@@ -20,9 +20,9 @@ function getTempDir(): string
 {
 	$dir = __DIR__ . '/tmp/' . getmypid();
 
-	if (empty($GLOBALS['\\lock'])) {
+	if (empty($GLOBALS['\lock'])) {
 		// garbage collector
-		$GLOBALS['\\lock'] = $lock = fopen(__DIR__ . '/lock', 'w');
+		$GLOBALS['\lock'] = $lock = fopen(__DIR__ . '/lock', 'w');
 		if (rand(0, 100)) {
 			flock($lock, LOCK_SH);
 			@mkdir(dirname($dir));
